@@ -8,7 +8,7 @@ package Sumu::Perl::Modules;
 
 =head1 VERSION
 
-version 0.1.1
+version 0.1.4
 
 =head2 Strictures
     Enable strict and warnings
@@ -20,7 +20,7 @@ use warnings;
 =head2 VERSION
 =cut
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.4';
 
 use parent qw(Exporter); 
 require Exporter; 
@@ -56,8 +56,6 @@ sub new {
 
 use ExtUtils::Installed;
 
-my $inst = ExtUtils::Installed->new();
-
 
 =head3 Sub _extutils
     Returns List of modules 
@@ -66,6 +64,8 @@ my $inst = ExtUtils::Installed->new();
 sub _extutils {
 
     my $c = shift;
+    
+    my $inst = ExtUtils::Installed->new();
 
     my @modules = $inst->modules();
 
@@ -90,7 +90,7 @@ sub _extutils {
 
         $mods .= qq{<tr> 
             <td>$serial</td> 
-            <td> <a href="_dirs/$_" title="$_">$_</a> </td> 
+            <td> <a href="/perl/_modules/_dirs/$_" title="$_">$_</a> </td> 
             <td>$module_version</td> 
             <td>$module_files</td> 
             <td> $mod_dirs </td> 
@@ -123,7 +123,7 @@ sub _dirs  {
     my $module = $in{module};
     chomp $module; 
 
-    $module =~ s!\\!\/!g;
+    my $inst = ExtUtils::Installed->new();
 
     #
     my @mod_dirs = $inst->directories("$module");
@@ -153,7 +153,7 @@ sub _dirs  {
         my $cust_filename = $_;
         $cust_filename =~ s!^\/home\/$current_user!!g;
         #
-        $files .= qq{<li> <a href="_doc/$_" title="$cust_filename">$cust_filename</a> </li>};
+        $files .= qq{<li> <a href="/perl/_modules/_doc/$_" title="$cust_filename">$cust_filename</a> </li>};
     }
     $files .= qq{</ol>};
 
@@ -177,8 +177,6 @@ sub _doc {
     #
     my $module = $in{module};
         chomp $module;
-
-    $module =~ s!\\!\/!g;
     
     my @doc = `perldoc $module`;
 
@@ -190,7 +188,7 @@ sub _doc {
         $out .= qq{$_<br>};
     }
 
-    return ($module, $out);
+    return($module, $out);
 
     #
 
